@@ -344,10 +344,10 @@ class MotofitMainWindow(QtWidgets.QMainWindow):
         except Exception as e:
             version = state.get("refnx.version", "N/A")
             msg(
-                "Failed to load experiment. It may have been saved in a"
-                " previous refnx version ({}). Please use that version to"
-                " continue with analysis, refnx will now"
-                " close.".format(version)
+                f"Failed to load experiment. It may have been saved in a"
+                f" previous refnx version ({version}). Please use that"
+                f" version to continue with analysis, refnx will now"
+                f" close."
             )
             raise e
 
@@ -731,7 +731,7 @@ class MotofitMainWindow(QtWidgets.QMainWindow):
         cwd = Path.cwd()
         suggested_name = cwd / "coefficients.csv"
         fname, ok = getsavefilename(
-            self, "Exported file name:", suggested_name
+            self, "Exported file name:", str(suggested_name)
         )
         if not ok:
             return
@@ -1202,7 +1202,7 @@ class MotofitMainWindow(QtWidgets.QMainWindow):
         ]
         if not _component:
             return msg(
-                "Select a single Component within a Structure to" " remove"
+                "Select a single Component within a Structure to remove"
             )
 
         # work out which component you have.
@@ -1519,9 +1519,10 @@ class MotofitMainWindow(QtWidgets.QMainWindow):
                         if progress.wasCanceled():
                             raise StopIteration("Sampling aborted")
 
-                with open(
-                    folder / "steps.chain", "w"
-                ) as f, get_context().Pool() as workers:
+                with (
+                    open(folder / "steps.chain", "w") as f,
+                    get_context().Pool() as workers,
+                ):
                     fitter.sample(
                         nsteps,
                         f=f,
@@ -1777,7 +1778,7 @@ class MotofitMainWindow(QtWidgets.QMainWindow):
         datastore = self.treeModel.datastore
 
         self.data_object_selector.setWindowTitle(
-            "Select equivalent datasets" " to link"
+            "Select equivalent datasets to link"
         )
         ok = self.data_object_selector.exec()
         if not ok:
@@ -2288,8 +2289,9 @@ class ProgressCallback(QtWidgets.QDialog):
             self.ui.timer.display(float(self.elapsed))
             self.last_time = new_time
 
-            text = "Chi2 : {}\nIterations : {}".format(
-                self.objective.chisqr(xk), self.iterations
+            text = (
+                f"Chi2 : {self.objective.chisqr(xk)}\n"
+                f"Iterations : {self.iterations}"
             )
 
             self.ui.values.setPlainText(text)
@@ -2343,7 +2345,6 @@ class NavToolBar(NavigationToolbar):
 
 
 class MyReflectivityGraphs(FigureCanvas):
-
     """Ultimately, this is a QWidget (as well as a FigureCanvasAgg, etc.)."""
 
     def __init__(self, parent=None):
@@ -2533,7 +2534,6 @@ class MyReflectivityGraphs(FigureCanvas):
 
 
 class MySLDGraphs(FigureCanvas):
-
     """Ultimately, this is a QWidget (as well as a FigureCanvasAgg, etc.)."""
 
     def __init__(self, parent=None):
@@ -2667,7 +2667,7 @@ class OpenMenu(QtWidgets.QMenu):
         self.addSeparator()
         self.add_mixed_area = self.addAction("Mixed area - add a structure")
         self.remove_mixed_area = self.addAction(
-            "Mixed area - remove a" " structure"
+            "Mixed area - remove a structure"
         )
 
     def __call__(self, position):
