@@ -20,11 +20,12 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THIS SOFTWARE.
 
 """
+
 # -*- coding: utf-8 -*-
 
 from collections import UserList
 import numbers
-import operator
+import operator as op
 
 import numpy as np
 from scipy.stats import norm
@@ -39,7 +40,7 @@ from refnx._lib import flatten
 from refnx.analysis import Parameters, Parameter, possibly_create_parameter
 from refnx.analysis.parameter import BaseParameter
 from refnx.reflect.interface import Interface, Erf, Step
-from refnx.reflect.reflect_model import get_reflect_backend
+from refnx.reflect.reflect_model import get_reflect_backend, SpinChannel
 
 # contracting the SLD profile can greatly speed a reflectivity calculation up.
 contract_by_area = refcalc._contract_by_area
@@ -171,11 +172,11 @@ class Structure(UserList):
 
     def __str__(self):
         s = list()
-        s.append("{:_>80}".format(""))
-        s.append("Structure: {0: ^15}".format(str(self.name)))
-        s.append("solvent: {0}".format(repr(self._solvent)))
-        s.append("reverse structure: {0}".format(str(self.reverse_structure)))
-        s.append("contract: {0}\n".format(str(self.contract)))
+        s.append(f"{'':_>80}")
+        s.append(f"Structure: {self.name: ^15}")
+        s.append(f"solvent: {(self._solvent)!r}")
+        s.append(f"reverse structure: {self.reverse_structure}")
+        s.append(f"contract: {self.contract}\n")
 
         for component in self:
             s.append(str(component))
@@ -184,11 +185,11 @@ class Structure(UserList):
 
     def __repr__(self):
         return (
-            "Structure(components={data!r},"
-            " name={_name!r},"
-            " solvent={_solvent!r},"
-            " reverse_structure={_reverse_structure},"
-            " contract={contract})".format(**self.__dict__)
+            f"Structure(components={self.data!r},"
+            f" name={self._name!r},"
+            f" solvent={self._solvent!r},"
+            f" reverse_structure={self._reverse_structure},"
+            f" contract={self.contract})"
         )
 
     def append(self, item):
@@ -206,7 +207,7 @@ class Structure(UserList):
 
         if not isinstance(item, Component):
             raise ValueError(
-                "You can only add Component objects to a" " structure"
+                "You can only add Component objects to a structure"
             )
         super().append(item)
 
@@ -253,6 +254,14 @@ class Structure(UserList):
     def reverse_structure(self, reverse_structure):
         self._reverse_structure = reverse_structure
 
+    @classmethod
+    def from_slabs(cls, slabs):
+        s = []
+        for slab in slabs:
+            _slab = Slab(slab[0], complex(slab[1], slab[2]), slab[3])
+            s.append(_slab)
+        return cls(s)
+
     def slabs(self, **kwds):
         r"""
 
@@ -271,7 +280,14 @@ class Structure(UserList):
             - slab[N, 3]
                roughness between layer N and N-1
             - slab[N, 4]
-               volume fraction of solvent in layer N.
+               volume fraction of solvent in layer N
+
+            if the system is magnetic then there are two extra columns
+
+            - slab[N, 5]
+                Magnetic SLD correction
+            - slab[N, 6]
+                Angle that magnetic moment makes w.r.t applied field
 
         Notes
         -----
@@ -287,8 +303,8 @@ class Structure(UserList):
             return None
 
         if not (
-            isinstance(self.data[-1], (Slab, MixedSlab))
-            and isinstance(self.data[0], (Slab, MixedSlab))
+            isinstance(self.data[-1], (Slab, MixedSlab, MagneticSlab))
+            and isinstance(self.data[0], (Slab, MixedSlab, MagneticSlab))
         ):
             raise ValueError(
                 "The first and last Components in a Structure"
@@ -307,12 +323,7 @@ class Structure(UserList):
             # if all the interfaces are Gaussian, then simply concatenate
             # the default slabs property of each component.
             sl = [c.slabs(structure=self) for c in self.components]
-
-            try:
-                slabs = np.concatenate(sl)
-            except ValueError:
-                # some of slabs may be None. np can't concatenate arr and None
-                slabs = np.concatenate([s for s in sl if s is not None])
+            slabs = _concatenate_slabs(sl)
         else:
             # there is a non-default interfacial roughness, create a microslab
             # representation
@@ -364,7 +375,12 @@ class Structure(UserList):
         """
         # solvate the slabs from each component
         sl = [c.slabs(structure=self) for c in self.components]
-        total_slabs = np.concatenate(sl)
+        total_slabs = _concatenate_slabs(sl)
+        if self.is_magnetic:
+            raise RuntimeError(
+                "Microslicing not available for magnetic systems yet"
+            )
+
         total_slabs[1:-1] = self.overall_sld(total_slabs[1:-1], self.solvent)
 
         total_slabs[:, 0] = np.fabs(total_slabs[:, 0])
@@ -439,6 +455,13 @@ class Structure(UserList):
         """
         return [c.interfaces for c in self.components]
 
+    @property
+    def is_magnetic(self):
+        """
+        Are any of the Components in the Structure magnetic?
+        """
+        return any([c.is_magnetic for c in self.components])
+
     def overall_sld(self, slabs, solvent):
         """
         Performs a volume fraction weighted average of the material SLD in a
@@ -462,7 +485,7 @@ class Structure(UserList):
 
         return overall_sld(slabs, solv)
 
-    def reflectivity(self, q, threads=0):
+    def reflectivity(self, q, threads=0, spin=None):
         """
         Calculate theoretical reflectivity of this structure
 
@@ -476,6 +499,13 @@ class Structure(UserList):
             module. The option is ignored if using the pure python calculator,
             ``_reflect``. If `threads == 0` then all available processors are
             used.
+        spin : refnx.reflect.SpinChannel
+            Enum specifying which spin-state to calculate. None is unpolarised.
+
+        Returns
+        -------
+        reflectivity : np.ndarray
+            Reflectivity corresponding to each of the Q-points.
 
         Notes
         -----
@@ -490,7 +520,32 @@ class Structure(UserList):
         `Structure.contract` property can be used.
         """
         abeles = get_reflect_backend()
-        return abeles(q, self.slabs()[..., :4], threads=threads)
+        slabs = self.slabs()
+        if slabs.shape[1] == 5:
+            # unpolarised
+            return abeles(q, slabs[..., :4], threads=threads)
+        elif slabs.shape[1] == 7:
+            # magnetic system
+            _c = {
+                SpinChannel.UP_UP: 0,
+                SpinChannel.UP_DOWN: 1,
+                SpinChannel.DOWN_UP: 2,
+                SpinChannel.DOWN_DOWN: 3,
+            }
+            if spin is None:
+                # TODO: implement unpolarised reflectivity calc for
+                # magnetic system
+                raise ValueError(
+                    "Unpolarised reflectivity calculation not yet"
+                    " possible for magnetic system."
+                )
+            slabs = np.take_along_axis(
+                slabs, np.array([0, 1, 2, 3, 5, 6])[None, :], axis=1
+            )
+            from refnx.reflect import _creflect
+
+            ref = _creflect.gepore(q, slabs)
+            return ref[_c[spin]]
 
     def sld_profile(self, z=None, align=0, max_delta_z=None):
         """
@@ -538,7 +593,7 @@ class Structure(UserList):
             align = int(align)
             if align >= len(slabs) - 1 or align < -1 * len(slabs):
                 raise RuntimeError(
-                    "abs(align) has to be less than " "len(slabs) - 1"
+                    "abs(align) has to be less than len(slabs) - 1"
                 )
             # to figure out the offset you need to know the cumulative distance
             # to the interface
@@ -621,7 +676,7 @@ class Structure(UserList):
         this structure.
 
         """
-        p = Parameters(name="Structure - {0}".format(self.name))
+        p = Parameters(name=f"Structure - {self.name}")
         p.extend([component.parameters for component in self.components])
         if self._solvent is not None:
             p.append(self.solvent.parameters)
@@ -698,13 +753,13 @@ class Structure(UserList):
         ----------
         pvals : np.ndarray, optional
             Numeric values for the Parameter's that are varying
-        samples: number
+        samples : number
             If this structures constituent parameters have been sampled, how
             many samples you wish to plot on the graph.
-        fig: Figure instance, optional
+        fig : Figure instance, optional
             If `fig` is not supplied then a new figure is created. Otherwise
             the graph is created on the current axes on the supplied figure.
-        align: int, optional
+        align : int, optional
             Aligns the plotted structures around a specified interface in the
             slab representation of a Structure. This interface will appear at
             z = 0 in the sld plot. Note that Components can consist of more
@@ -745,6 +800,97 @@ class Structure(UserList):
 
         return fig, ax
 
+    def to_orso(self):
+        """
+        Creates an ORSO model language description of a Structure. Only works with Structures solely consisting of Slabs at the moment
+
+        Returns
+        -------
+        model : :class:`orso.fileio.model_language.SampleModel`
+        """
+        from orsopy.fileio import model_language as ml
+
+        defaults = ml.ModelParameters(
+            length_unit="angstrom", sld_unit="1/angstrom^2"
+        )
+        layers = {}
+
+        for i, comp in enumerate(self.components):
+            if not isinstance(comp, Slab):
+                raise RuntimeError(
+                    "Can only export Structure solely consisting of Slabs at the moment"
+                )
+
+            if isinstance(comp.sld, MaterialSLD):
+                mat = ml.Material(
+                    comp.sld.formula, mass_density=comp.sld.density
+                )
+            else:
+                _csld = complex(comp.sld) * 1e-6
+                _csld = ml.ComplexValue(_csld.real, _csld.imag)
+                mat = ml.Material(sld=_csld)
+
+            if comp.name:
+                ni = comp.name
+            else:
+                ni = f"m{i}"
+
+            layers[ni] = ml.Layer(
+                thickness=comp.thick, roughness=comp.rough, material=mat
+            )
+
+        stack = " | ".join(list(layers.keys()))
+        model = ml.SampleModel(
+            stack=stack,
+            layers=layers,
+            globals=defaults,
+            reference="ORSO model language | 1.0",
+        )
+        return model
+
+    @classmethod
+    def from_orso(cls, sample_model):
+        """
+        Creates a Structure from an :class:`orso.fileio.model_language.SampleModel`
+
+        Parameters
+        ----------
+        sample_model : :class:`orso.fileio.model_language.SampleModel`
+
+        Returns
+        -------
+        structure : Structure
+
+        Example
+        -------
+
+        >>> with open('oml.yml') as f:
+        ...     dct = yaml.safe_load(f)
+        >>> model = SampleModel(**dct)
+
+        """
+        layers = sample_model.resolve_to_layers()
+        s = Structure()
+
+        for layer in layers:
+            mat = layer.material
+            if mat.formula is not None:
+                sld = MaterialSLD(
+                    mat.formula, density=mat.mass_density.magnitude
+                )
+            else:
+                sld = SLD(mat.get_sld() * 1e6)
+                print(sld)
+
+            slab = Slab(
+                layer.thickness.magnitude,
+                sld,
+                layer.roughness.magnitude,
+                name=layer.original_name,
+            )
+            s |= slab
+        return s
+
 
 def overall_sld(slabs, solvent):
     """
@@ -769,6 +915,47 @@ def overall_sld(slabs, solvent):
     return slabs
 
 
+def _concatenate_slabs(sl):
+    """
+    Concatenates the slab representation. Entries that have 5 columns are
+    non-magnetic, entries with 7 columns are magnetic and need a wider
+    representation.
+
+    Parameters
+    ----------
+    sl: sequence
+        An iterable containing the slab representation of each Component.
+    """
+    try:
+        # they may all be the same size, in which case don't waste time
+        v = np.concatenate(sl)
+        return v
+    except ValueError:
+        # at this point there may be some magnetic slabs, or some entries may
+        # be None.
+        pass
+
+    cols = [s.shape[1] if s is not None else s for s in sl]
+    is_magnetic = 7 in cols
+    if is_magnetic:
+        # work out total size of slab array
+        rows = np.sum([s.shape[0] for s in sl if s is not None])
+        slabs = np.zeros((rows, 7))
+        # automatically align magnetic moment with applied field, assuming
+        # applied field is in the plane of the sample
+        slabs[:, -1] = 90.0
+        idx = 0
+        for s in sl:
+            if s is None:
+                continue
+            shp = s.shape
+            slabs[idx : idx + shp[0], : shp[1]] = s
+            idx += shp[0]
+        return slabs
+    else:
+        return np.concatenate([s for s in sl if s is not None])
+
+
 class Scatterer:
     """
     Abstract base class for something that will have a scattering length
@@ -782,7 +969,7 @@ class Scatterer:
 
     def __str__(self):
         sld = complex(self)
-        return "SLD = {0} x10**-6 Å**-2".format(sld)
+        return f"SLD = {sld} x10**-6 Å**-2"
 
     def __complex__(self):
         raise NotImplementedError
@@ -896,9 +1083,7 @@ class SLD(Scatterer):
         self._parameters = Parameters(name=name)
 
     def __repr__(self):
-        return "SLD([{real!r}, {imag!r}]," " name={name!r})".format(
-            **self.__dict__
-        )
+        return f"SLD([{self.real!r}, {self.imag!r}], name={self.name!r})"
 
     def __complex__(self):
         sldc = complex(self.real.value, self.imag.value)
@@ -968,16 +1153,12 @@ class MaterialSLD(Scatterer):
         self.dispersive = True
 
     def __repr__(self):
-        d = {
-            "compound": self._compound,
-            "density": self.density,
-            "wavelength": self.wavelength,
-            "probe": self.probe,
-            "name": self.name,
-        }
         return (
-            "MaterialSLD({compound!r}, {density!r}, probe={probe!r},"
-            " wavelength={wavelength!r}, name={name!r})".format(**d)
+            f"MaterialSLD({self._compound!r}, "
+            f"{self.density!r}, "
+            f"probe={self.probe!r}, "
+            f"wavelength={self.wavelength!r}, "
+            f"name={self.name!r})"
         )
 
     @property
@@ -1034,13 +1215,28 @@ class MaterialSLD(Scatterer):
         return self._parameters
 
 
+def possibly_create_scatterer(obj):
+    """
+    Possibly create an SLD object from float, complex, SLD
+
+    Parameters
+    ----------
+    obj: float, complex, Parameter, Parameters, Scatterer
+        object to coerce into a Scatterer
+    """
+    if isinstance(obj, Scatterer):
+        return obj
+    else:
+        return SLD(obj)
+
+
 class Component:
     """
     A base class for describing the structure of a subset of an interface.
 
     Parameters
     ----------
-    name : str, optional
+    name: str, optional
         The name associated with the Component
 
     Notes
@@ -1054,6 +1250,10 @@ class Component:
         self.name = name
         self._interfaces = None
 
+    @property
+    def is_magnetic(self):
+        return False
+
     def __or__(self, other):
         """
         OR'ing components can create a :class:`Structure`.
@@ -1098,7 +1298,7 @@ class Component:
             The created Structure
         """
         # convert to integer, should raise an error if there's a problem
-        n = operator.index(n)
+        n = op.index(n)
         if n < 1:
             return Structure()
         elif n == 1:
@@ -1117,7 +1317,7 @@ class Component:
         :class:`refnx.analysis.Parameters` associated with this component
         """
         raise NotImplementedError(
-            "A component should override the parameters " "property"
+            "A component should override the parameters property"
         )
 
     @property
@@ -1188,7 +1388,7 @@ class Component:
         """
 
         raise NotImplementedError(
-            "A component should override the slabs " "property"
+            "A component should override the slabs property"
         )
 
     def logp(self):
@@ -1214,7 +1414,7 @@ class Slab(Component):
     thick : refnx.analysis.Parameter or float
         thickness of slab (Angstrom)
     sld : :class:`refnx.reflect.Scatterer`, complex, or float
-        (complex) SLD of film (/1e-6 Angstrom**2)
+        (complex) SLD of film (/1e-6 Angstrom**-2)
     rough : refnx.analysis.Parameter or float
         roughness on top of this slab (Angstrom)
     name : str
@@ -1232,10 +1432,7 @@ class Slab(Component):
         self.thick = possibly_create_parameter(
             thick, name=f"{name} - thick", units="Å"
         )
-        if isinstance(sld, Scatterer):
-            self.sld = sld
-        else:
-            self.sld = SLD(sld)
+        self.sld = possibly_create_scatterer(sld)
         self.rough = possibly_create_parameter(
             rough, name=f"{name} - rough", units="Å"
         )
@@ -1311,7 +1508,7 @@ class MixedSlab(Component):
         thickness of slab (Angstrom)
     sld_list : sequence of {refnx.reflect.Scatterer, complex, float}
         Sequence of (complex) SLDs that are contained in film
-        (/1e-6 Angstrom**2)
+        (/1e-6 Angstrom**-2)
     vf_list : sequence of refnx.analysis.Parameter or float
         relative volume fractions of each of the materials contained in the
         film.
@@ -1482,7 +1679,7 @@ class Stack(Component, UserList):
                 self.data.append(c)
             else:
                 raise ValueError(
-                    "You can only initialise a Stack with" " Components"
+                    "You can only initialise a Stack with Components"
                 )
 
     def __setitem__(self, i, v):
@@ -1490,21 +1687,21 @@ class Stack(Component, UserList):
 
     def __str__(self):
         s = list()
-        s.append("{:=>80}".format(""))
+        s.append(f"{'' :=>80}")
 
         s.append(f"Stack start: {int(round(abs(self.repeats.value)))} repeats")
         for component in self:
             s.append(str(component))
         s.append("Stack finish")
-        s.append("{:=>80}".format(""))
+        s.append(f"{'' :=>80}")
 
         return "\n".join(s)
 
     def __repr__(self):
         return (
-            "Stack(name={name!r},"
-            " components={data!r},"
-            " repeats={repeats!r})".format(**self.__dict__)
+            f"Stack(name={self.name!r},"
+            f" components={self.data!r},"
+            f" repeats={self.repeats!r})"
         )
 
     def append(self, item):
@@ -1522,7 +1719,7 @@ class Stack(Component, UserList):
 
         if not isinstance(item, Component):
             raise ValueError(
-                "You can only add Component objects to a" " structure"
+                "You can only add Component objects to a structure"
             )
         self.data.append(item)
 
@@ -1545,10 +1742,9 @@ class Stack(Component, UserList):
             self.solvent = structure.solvent
 
         repeats = int(round(abs(self.repeats.value)))
+        sl = [c.slabs(structure=self) for c in self.components]
 
-        slabs = np.concatenate(
-            [c.slabs(structure=self) for c in self.components]
-        )
+        slabs = _concatenate_slabs(sl)
 
         if repeats > 1:
             slabs = np.concatenate([slabs] * repeats)
@@ -1591,7 +1787,7 @@ class Stack(Component, UserList):
         this structure.
 
         """
-        p = Parameters(name="Stack - {0}".format(self.name))
+        p = Parameters(name=f"Stack - {self.name}")
         p.append(self.repeats)
         p.extend([component.parameters for component in self.components])
         return p
@@ -1616,6 +1812,136 @@ class Stack(Component, UserList):
             raise ValueError()
         return self
 
+    @property
+    def is_magnetic(self):
+        return any([c.is_magnetic for c in self])
+
+
+class MagneticSlab(Component):
+    """
+    A slab component has uniform SLD over its thickness.
+
+    Parameters
+    ----------
+    thick : refnx.analysis.Parameter or float
+        thickness of slab (Angstrom)
+    sld : :class:`refnx.reflect.Scatterer`, complex, or float
+        (complex) nuclear SLD of film (/1e-6 Angstrom**-2)
+    rough : refnx.analysis.Parameter or float
+        roughness on top of this slab (Angstrom)
+    rhoM : refnx.analysis.Parameter or float
+        magnetic SLD of film (/1e-6 Angstrom**-2)
+    thetaM : refnx.analysis.Parameter or float
+        Magnetic angle of the layer (degrees). See
+        https://github.com/reflectivity/analysis/tree/master/validation
+        for geometry details.
+        For a magnetic moment to be parallel or anti-parallel to an applied
+        field in the plane of the sample (`Aguide=270` or `90`), `thetaM`
+        should be 90 or -90 deg respectively. If `thetaM = 0` then the moment
+        in the film is perpendicular to the applied field and spin flip will
+        be maximised.
+    name : str
+        Name of this slab
+    interface : {:class:`Interface`, None}, optional
+        The type of interfacial roughness associated with the Slab.
+        If `None`, then the default interfacial roughness is an Error
+        function (also known as Gaussian roughness).
+
+    Notes
+    -----
+    For the applied field to be in the plane of the sample (perpendicular to
+    the beam propagation direction) `Aguide` should be 270 or 90 degrees.
+    For the magnetic moment to be parallel or anti-parallel to the applied
+    field `thetaM` should be 90 or -90 respectively.
+    """
+
+    def __init__(
+        self,
+        thick,
+        sld,
+        rough,
+        rhoM,
+        thetaM=90.0,
+        name="",
+        interface=None,
+    ):
+        super().__init__(name=name)
+        self.thick = possibly_create_parameter(
+            thick, name=f"{name} - thick", units="Å"
+        )
+        if isinstance(sld, Scatterer):
+            self.sld = sld
+        else:
+            self.sld = SLD(sld)
+        self.rough = possibly_create_parameter(
+            rough, name=f"{name} - rough", units="Å"
+        )
+        self.rhoM = possibly_create_parameter(
+            rhoM,
+            name=f"{name} - rhoM",
+        )
+        self.thetaM = possibly_create_parameter(
+            thetaM,
+            name=f"{name} - thetaM",
+        )
+        self._parameters = Parameters(name=self.name)
+        self.interfaces = interface
+
+    def __repr__(self):
+        return (
+            f"MagneticSlab({self.thick!r}, {self.sld!r}, {self.rough!r},"
+            f" name={self.name!r}, rhoM={self.rhoM!r},"
+            f" thetaM={self.thetaM!r}, interface={self.interfaces!r})"
+        )
+
+    @property
+    def is_magnetic(self):
+        return True
+
+    def __str__(self):
+        return str(self.parameters)
+
+    @property
+    def parameters(self):
+        """
+        :class:`refnx.analysis.Parameters` associated with this component
+
+        """
+        self._parameters.name = self.name
+        self._parameters.data = [
+            self.thick,
+            self.sld.parameters,
+            self.rough,
+            self.rhoM,
+            self.thetaM,
+        ]
+        return self._parameters
+
+    def slabs(self, structure=None):
+        """
+        Slab representation of this component. See :class:`Component.slabs`
+        """
+        # speculative shortcut to prevent a number of attribute retrievals
+        if self.sld.dispersive:
+            sldc = self.sld.complex(getattr(structure, "wavelength", None))
+        else:
+            sldc = complex(self.sld)
+
+        return np.array(
+            [
+                [
+                    self.thick.value,
+                    sldc.real,
+                    sldc.imag,
+                    self.rough.value,
+                    0.0,
+                    self.rhoM.value,
+                    self.thetaM.value,
+                ]
+            ],
+            dtype=float,
+        )
+
 
 def _profile_slicer(z, sld_profile, slice_size=None):
     """
@@ -1689,14 +2015,14 @@ def _profile_slicer(z, sld_profile, slice_size=None):
 
 def sld_profile(slabs, z=None, max_delta_z=None):
     """
-    Calculates an SLD profile, as a function of distance through the
+    Calculates a nuclear SLD profile, as a function of distance through the
     interface.
 
     Parameters
     ----------
     slabs : :class:`np.ndarray`
         Slab representation of this structure.
-        Has shape (N, 5).
+        Has shape (N, 5) or (N, 7) for magnetic systems.
 
         - slab[N, 0]
            thickness of layer N
@@ -1775,3 +2101,84 @@ def sld_profile(slabs, z=None, max_delta_z=None):
         sld += delta_rho[i] * f(zed, scale=sigma[i], loc=dist[i])
 
     return zed, sld
+
+
+def create_occupancy(structure, solvent_slab=-1):
+    """
+    Creates a volume fraction (occupancy) profile for a given Structure.
+
+    Parameters
+    ----------
+    structure: Structure
+
+    solvent_slab: {int, None}
+        Defines which slab in `structure` is specified to contain
+        the solvent. Use -1 if solvation is done by the backing medium
+        If solvation is done by fronting medium use 0.
+        If None, then solvation is done by neither fronting or backing,
+        but by another material. This might be a solvent vapour in an
+        air-solid measurement.
+
+    Returns
+    -------
+    z, vfp: np.ndarray
+        z is the distance through the interface, Angstrom
+
+        vfp is the array containing the volume fraction profiles for
+        each of the slabs from the structure.
+
+        In the case where `solvent_slab is None` then
+        `vfp.shape == (len(structure.slabs()) + 1, len(z))` and the last
+        row contains the solvent vfp.
+
+        In the case where solvent_slab is one of the slab materials
+        (e.g. fronting or backing) then
+        `vfp.shape == (len(structure.slabs()), len(z))`, with
+        `vfp[solvent_slab]` containing the vfp for the solvent.
+
+    Notes
+    -----
+    If a Component in your Structure has more than one row in its slab
+    representation then you will need to aggregate those slabs manually if you
+    wish them to appear together.
+    e.g. let's say that the third Component (indexed from zero) has
+    `len(Component.slabs) == 20`. To obtain the volume fraction for that
+    Component you would need to do:
+
+    >>> import matplotlib.pyplot as plt
+    >>> z, vfps = create_occupancy(s)
+    >>> # third component is at index 2.
+    >>> vfps_my_component = np.sum(vfps[2:20+2], axis=0)
+    >>> plt.plot(z, vfps_my_component)
+
+    """
+    _slabs = structure.slabs()
+
+    vf = 1 - _slabs[:, 4]
+
+    if solvent_slab is None:
+        nvfp = len(_slabs) + 1
+    else:
+        nvfp = len(_slabs)
+
+    z, sldp = sld_profile(_slabs)
+    vfp = np.zeros((nvfp, len(z)), float)
+
+    for i in range(len(_slabs)):
+        _slabs[:, 1:3] = 0
+        _slabs[i, 1] = vf[i]
+        _vfp = sld_profile(_slabs, z=z)[1]
+        vfp[i] = _vfp
+
+    # fix up the solvent vfp
+    _slabs[:, 1] = 1 - vf
+
+    if solvent_slab is None:
+        _vfp = sld_profile(_slabs, z=z)[1]
+        vfp[-1] = _vfp
+    else:
+        _slabs[solvent_slab, 1] = 1
+        _vfp = sld_profile(_slabs, z=z)[1]
+        vfp[solvent_slab] = _vfp
+
+    return z, vfp
