@@ -21,6 +21,7 @@ from refnx.analysis import (
 )
 from refnx.reflect import (
     SLD,
+    MaterialSLD,
     ReflectModel,
     ReflectModelTL,
     PolarisedReflectModel,
@@ -182,13 +183,14 @@ class TestReflect:
         kf = kn(q, sld2, sld2)
         kb = kn(q, sld1, sld2)
         reflectance = (kf - kb) / (kf + kb)
-        reflectivity = reflectance * np.conj(reflectance)
+        reflectivity = np.real(reflectance * np.conj(reflectance))
 
         # now from refnx code
         struct = SLD(sld2)(0, 0) | SLD(sld1)(0, 0)
         slabs = struct.slabs()[..., :4]
         with use_reflect_backend(backend) as kernel:
-            assert_allclose(kernel(q, slabs), reflectivity, rtol=1e-14)
+            # adjusted rtol to allow leeway for 32 bit FPU
+            assert_allclose(kernel(q, slabs), reflectivity, rtol=1e-9)
 
     @pytest.mark.filterwarnings("ignore:Using the SLOW")
     def test_scale_bkg_kernel(self):
@@ -515,6 +517,28 @@ class TestReflect:
             atol=2e-7,
         )
 
+        si = MaterialSLD("Si", 2.33, probe="x-ray")
+        au = MaterialSLD("Au", 19.33, probe="x-ray")
+        air = SLD(0.0)
+        s = air() | au(200, 4) | si(0, 3)
+        rff3_model = ReflectModelTL(s, bkg=0.0, dq=0.0)
+
+        _q = np.geomspace(0.01, 1.0, 500)
+        fa = general.angle(_q[:250], 1.0)
+        sa = general.angle(_q[250:], 2.0)
+        lam = np.ones(shape=(500,), dtype=np.float64)
+        lam[250:] = 2.0
+        tl = np.c_[np.r_[fa, sa], lam]
+        r = rff3_model.model(tl)
+
+        # comparison to normal ReflectModel
+        rff3_modelc = ReflectModel(s, bkg=0, dq=0.0)
+        s.wavelength = 1.0
+        r1 = rff3_modelc.model(_q[:250])
+        s.wavelength = 2.0
+        r2 = rff3_modelc.model(_q[250:])
+        assert_allclose(r, np.r_[r1, r2])
+
     def test_mixed_reflectivity_model(self):
         # test that mixed area model works ok.
 
